@@ -19,7 +19,6 @@
 #ifndef __FONTSELECTION_H__
 #define __FONTSELECTION_H__
 
-char *
-open_fontselection (char * init);
+char *open_fontselection (char *init);
 
 #endif
