@@ -1,6 +1,5 @@
 /* XPM */
-static char *mininf[] =
-{
+static char *mininf[] = {
   "19 19 4 1",
   "+ c none",
   "# c #183c59",
@@ -24,4 +23,5 @@ static char *mininf[] =
   "+++a#bbbbbbbbb#a+++",
   "++++a##bbbbb##a++++",
   "+++++aa#####aa+++++",
-  "+++++++aaaaa+++++++"};
+  "+++++++aaaaa+++++++"
+};
