@@ -44,13 +44,16 @@
 #include "xfclock.h"
 #include "xfclock_opt.h"
 
+#include "appointments.h"
+
 #ifdef DMALLOC
 #  include "dmalloc.h"
 #endif
 
 #include "xfclock_icon.xpm"
 
-gint update_xfclock_date_timer (GtkWidget * widget)
+gint
+update_xfclock_date_timer (GtkWidget * widget)
 {
   time_t ticks;
   struct tm *tm;
@@ -59,9 +62,10 @@ gint update_xfclock_date_timer (GtkWidget * widget)
   static gint year = -1;
   guint cal_day, cal_mon, cal_year;
 
-  if (!timeout){
-	  timeout=TRUE;
-	  return TRUE;
+  if (!timeout)
+  {
+    timeout = TRUE;
+    return TRUE;
   }
 
   g_return_val_if_fail (widget != NULL, FALSE);
@@ -70,21 +74,18 @@ gint update_xfclock_date_timer (GtkWidget * widget)
 
   ticks = time (0);
   tm = localtime (&ticks);
-  gtk_calendar_get_date (GTK_CALENDAR (widget), &cal_year, &cal_mon,
-			 &cal_day);
-  if ((mday != tm->tm_mday) || (mon != tm->tm_mon) || (year != tm->tm_year)
-      || (cal_day != tm->tm_mday) || (cal_mon != tm->tm_mon)
-      || (cal_year != tm->tm_year))
-    {
-      mday = tm->tm_mday;
-      mon = tm->tm_mon;
-      year = tm->tm_year;
+  gtk_calendar_get_date (GTK_CALENDAR (widget), &cal_year, &cal_mon, &cal_day);
+  if ((mday != tm->tm_mday) || (mon != tm->tm_mon) || (year != tm->tm_year) || (cal_day != tm->tm_mday) || (cal_mon != tm->tm_mon) || (cal_year != tm->tm_year))
+  {
+    mday = tm->tm_mday;
+    mon = tm->tm_mon;
+    year = tm->tm_year;
 
-      gtk_calendar_select_day (GTK_CALENDAR (widget), mday);
-      gtk_calendar_select_month (GTK_CALENDAR (widget), mon, year + 1900);
-      mark_holy_days(widget);
+    gtk_calendar_select_day (GTK_CALENDAR (widget), mday);
+    gtk_calendar_select_month (GTK_CALENDAR (widget), mon, year + 1900);
+    mark_holy_days (widget);
 
-    }
+  }
   return TRUE;
 }
 
@@ -114,8 +115,7 @@ main (int argc, char *argv[])
   if ((current_config.w >= 0) && (current_config.h >= 0))
     gtk_widget_set_usize (window, current_config.w, current_config.h);
 
-  gtk_window_set_title (GTK_WINDOW (window),
-			_("XFClock - XFce Clock & Calendar"));
+  gtk_window_set_title (GTK_WINDOW (window), _("XFClock - XFce Clock & Calendar"));
 
   vbox = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (window), vbox);
@@ -123,11 +123,17 @@ main (int argc, char *argv[])
 
   handle_box = gtk_handle_box_new ();
   gtk_box_pack_start (GTK_BOX (vbox), handle_box, FALSE, FALSE, 0);
+  gtk_container_border_width (GTK_CONTAINER (handle_box), 2);
+
   if (current_config.menubar)
     gtk_widget_show (handle_box);
 
   main_frame = gtk_frame_new (NULL);
+#ifdef OLD_STYLE
+  gtk_frame_set_shadow_type (GTK_FRAME (main_frame), GTK_SHADOW_NONE);
+#else
   gtk_frame_set_shadow_type (GTK_FRAME (main_frame), GTK_SHADOW_OUT);
+#endif
   gtk_box_pack_start (GTK_BOX (vbox), main_frame, TRUE, TRUE, 0);
   gtk_widget_show (main_frame);
 
@@ -153,30 +159,24 @@ main (int argc, char *argv[])
   newstyle = gtk_style_copy (style);
   if (my_strncasecmp (current_config.font, "*", strlen (current_config.font)))
     setfontstyle (newstyle, current_config.font);
-  if ((current_config.fore_red >= 0) &&
-      (current_config.fore_green >= 0) && 
-      (current_config.fore_blue >= 0))
-    {
-      colors[0] = ((gdouble) current_config.fore_red) / COLOR_GDK;
-      colors[1] = ((gdouble) current_config.fore_green) / COLOR_GDK;
-      colors[2] = ((gdouble) current_config.fore_blue) / COLOR_GDK;
-      setfgstyle (newstyle, colors);
-    }
-  if ((current_config.back_red >= 0) &&
-      (current_config.back_green >= 0) && 
-      (current_config.back_blue >= 0))
-    {
-      colors[0] = ((gdouble) current_config.back_red) / COLOR_GDK;
-      colors[1] = ((gdouble) current_config.back_green) / COLOR_GDK;
-      colors[2] = ((gdouble) current_config.back_blue) / COLOR_GDK;
-      setbgstyle (newstyle, colors);
-    }
+  if ((current_config.fore_red >= 0) && (current_config.fore_green >= 0) && (current_config.fore_blue >= 0))
+  {
+    colors[0] = ((gdouble) current_config.fore_red) / COLOR_GDK;
+    colors[1] = ((gdouble) current_config.fore_green) / COLOR_GDK;
+    colors[2] = ((gdouble) current_config.fore_blue) / COLOR_GDK;
+    setfgstyle (newstyle, colors);
+  }
+  if ((current_config.back_red >= 0) && (current_config.back_green >= 0) && (current_config.back_blue >= 0))
+  {
+    colors[0] = ((gdouble) current_config.back_red) / COLOR_GDK;
+    colors[1] = ((gdouble) current_config.back_green) / COLOR_GDK;
+    colors[2] = ((gdouble) current_config.back_blue) / COLOR_GDK;
+    setbgstyle (newstyle, colors);
+  }
   gtk_widget_set_style (clock_widget, newstyle);
   my_gtk_clock_show_ampm (MY_GTK_CLOCK (clock_widget), current_config.ampm);
-  my_gtk_clock_show_military (MY_GTK_CLOCK (clock_widget),
-			      current_config.military);
-  my_gtk_clock_show_secs (MY_GTK_CLOCK (clock_widget),
-			  current_config.seconds);
+  my_gtk_clock_show_military (MY_GTK_CLOCK (clock_widget), current_config.military);
+  my_gtk_clock_show_secs (MY_GTK_CLOCK (clock_widget), current_config.seconds);
   if (current_config.digital)
     my_gtk_clock_set_mode (MY_GTK_CLOCK (clock_widget), MY_GTK_CLOCK_DIGITAL);
   else
@@ -188,29 +188,24 @@ main (int argc, char *argv[])
   calendar = gtk_calendar_new ();
   gtk_object_set_data (GTK_OBJECT (window), "calendar", calendar);
   gtk_box_pack_start (GTK_BOX (hbox), calendar, FALSE, FALSE, 0);
-  gtk_calendar_display_options (GTK_CALENDAR (calendar),
-		                current_config.calendar_opt);
-  if (calendar)
+  gtk_calendar_display_options (GTK_CALENDAR (calendar), current_config.calendar_opt);
+  if (current_config.calendar)
     gtk_widget_show (calendar);
 
   menu = create_menu (MY_GTK_CLOCK (clock_widget));
   gtk_container_add (GTK_CONTAINER (handle_box), menu);
   gtk_widget_show (menu);
 
-  gtk_signal_connect (GTK_OBJECT (eventbox), "button_press_event",
-		      GTK_SIGNAL_FUNC (show_popup_cb),
-		      (gpointer) clock_widget);
+  gtk_signal_connect (GTK_OBJECT (eventbox), "button_press_event", GTK_SIGNAL_FUNC (show_popup_cb), (gpointer) clock_widget);
 
-  gtk_signal_connect (GTK_OBJECT (window), "delete_event",
-		      GTK_SIGNAL_FUNC (delete_event), NULL);
-  gtk_signal_connect (GTK_OBJECT (calendar), "month_changed", 
-                           GTK_SIGNAL_FUNC (monthchanged),
-                           NULL);
-  timeout=TRUE;
+  gtk_signal_connect (GTK_OBJECT (window), "delete_event", GTK_SIGNAL_FUNC (delete_event), NULL);
+  gtk_signal_connect (GTK_OBJECT (calendar), "month_changed", GTK_SIGNAL_FUNC (monthchanged), NULL);
+  gtk_signal_connect (GTK_OBJECT (calendar), "day_selected_double_click", GTK_SIGNAL_FUNC (edit_appointments), NULL);
+
+  timeout = TRUE;
   update_xfclock_date_timer (calendar);
-  gtk_timeout_add (30000, /* 30 secs */
-		   (GtkFunction) update_xfclock_date_timer,
-		   (gpointer) calendar);
+  gtk_timeout_add (30000,	/* 30 secs */
+		   (GtkFunction) update_xfclock_date_timer, (gpointer) calendar);
 
   gtk_widget_show (window);
   set_icon (window, "XFClock", xfclock_icon_xpm);
