@@ -7,6 +7,8 @@
  * Olivier Fourdan (fourdan@xfce.org)
  * Heavily modified as part of the Xfce project (http://www.xfce.org)
  *
+ * Edscott Wilson Garcia Copyright 2001-2002
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -35,6 +37,8 @@ enum
   URI_FILE,
   URI_HTTP,
   URI_FTP,
+  URI_TAR,
+  URI_SMB
 }
 UriType;
 
@@ -46,11 +50,12 @@ typedef struct
 }
 uri, uri_t;
 
+int uri_type (char *s);
 char *uri_clear_path (const char *);
 char *uri_to_quoted_list (GList *);
 int uri_parse_list (const char *, GList **);
 int uri_remove_file_prefix (char *, int);
 int uri_remove_file_prefix_from_list (GList *);
-void uri_free_list (GList *);
+GList * uri_free_list (GList *);
 char *uri_basename (const char *);
 #endif
