@@ -140,7 +140,7 @@ gboolean check_hostname(char *host){
 	if (gethostname(buffer, 256) == 0)
 	{
 	  struct hostent *ent;
-	  buffer[256] = '\0';
+	  buffer[255] = '\0';
 	  testv=buffer;
 	  /*printf("dbg:%s==%s\n",host,testv);*/
 	  if (strncmp(host,testv,strlen(testv))==0) return TRUE;
@@ -863,7 +863,7 @@ set_title_ctree (GtkWidget * ctree, const char *path)
                   XA_STRING, /* GdkAtom type,*/
                   8, /* bit per data element: gint format*/
  	      	  GDK_PROP_MODE_APPEND,
-                  (guchar *)"-h",  
+                  (guchar *)"-H",  
 		  3); 
     gdk_property_change (gtk_widget_get_toplevel (GTK_WIDGET (ctree))->window,
 		  atomo,
