@@ -1,5 +1,19 @@
-
-
+/*  gxfce
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+*/
 
 /****************************************************************************
  * This module is based on Twm, but has been siginificantly modified 
@@ -46,6 +60,9 @@
 #ifndef _MENUS_
 #define _MENUS_
 
+#include <X11/Xlib.h>
+#include "utils.h"
+
 /* Function types used for formatting menus */
 
 #define FUNC_NO_WINDOW 0
@@ -54,8 +71,6 @@
 #define FUNC_TITLE 2
 #define FUNC_NOP 3
 
-#include "utils.h"
-
 typedef struct MenuItem
 {
   struct MenuItem *next;	/* next menu item */
@@ -73,11 +88,11 @@ typedef struct MenuItem
   short strlen;			/* strlen(item) */
   short strlen2;		/* strlen(item2) */
   short hotkey;			/* Hot key offset (pete@tecc.co.uk).
-				 * 0 - No hot key
-				 * +ve - offset to hot key char in item
-				 * -ve - offset to hot key char in item2
-				 * (offsets have 1 added, so +1 or -1
-				 * refer to the *first* character)
+				   * 0 - No hot key
+				   * +ve - offset to hot key char in item
+				   * -ve - offset to hot key char in item2
+				   * (offsets have 1 added, so +1 or -1
+				   * refer to the *first* character)
 				 */
 }
 MenuItem;
